@@ -33,6 +33,7 @@ auth_opts = [
     cfg.StrOpt("tenant_name",
                help="The non-administrative user's tenant name."),
     cfg.StrOpt("password",
+               secret=True,
                help="The non-administrative user's password."),
     cfg.StrOpt("auth_url",
                help="URL for where to find the OpenStack Identity public "
@@ -57,6 +58,7 @@ auth_opts = [
     cfg.StrOpt("admin_tenant_name",
                help="The administrative user's tenant name."),
     cfg.StrOpt("admin_password",
+               secret=True,
                help="The administrative user's password."),
     cfg.StrOpt("admin_auth_url",
                help="URL for where to find the OpenStack Identity admin "
@@ -143,6 +145,17 @@ share_opts = [
                default="stack",
                help="Username, that will be used in share access tests for "
                     "user type of access."),
+    cfg.StrOpt("replication_type",
+               default="readable",
+               choices=["readable", "writable", "dr"],
+               help="Replication type to be used when running replication "
+                    "tests. This option is ignored if run_replication_tests "
+                    "is set to False."),
+    cfg.BoolOpt("run_replication_tests",
+                default=True,
+                help="Defines whether to run tests for share replication "
+                     "or not. Disable this feature if manila driver used "
+                     "doesn't support share replication."),
     cfg.BoolOpt("run_snapshot_tests",
                 default=True,
                 help="Defines whether to run tests that use share snapshots "
@@ -165,6 +178,12 @@ share_opts = [
                 help="Defines whether to run mountable snapshots tests or "
                      "not. Disable this feature if used driver doesn't "
                      "support it."),
+    cfg.BoolOpt("run_manage_tests",
+                default=False,
+                help="Defines whether to run manage/unmanage tests or "
+                     "not. Disable this feature if used driver does not "
+                     "support it."),
+
 ]
 
 # 2. Generate config
