@@ -13,14 +13,10 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from six.moves.urllib import parse
-
 from manilaclient import api_versions
 from manilaclient import base
 from manilaclient.common.apiclient import base as common_base
 from manilaclient import exceptions
-from manilaclient import utils
-
 
 RESOURCES_PATH = '/share-networks'
 RESOURCE_PATH = "/share-networks/%s"
@@ -222,16 +218,7 @@ class ShareNetworkManager(base.ManagerWithFind):
 
         :rtype: list of :class:`NetworkInfo`
         """
-        if not search_opts:
-            search_opts = {}
-
-        query_string = ""
-        if search_opts:
-            search_opts = utils.unicode_key_value_to_string(search_opts)
-            params = sorted(
-                [(k, v) for (k, v) in list(search_opts.items()) if v])
-            if params:
-                query_string = "?%s" % parse.urlencode(params)
+        query_string = self._build_query_string(search_opts)
 
         if detailed:
             path = RESOURCES_PATH + "/detail" + query_string
